==> 0.3.2.tar.gz: lib/src/authenticators/user_password.dart <==
part of jaguar_auth.authenticators;

class WrapUsernamePasswordAuth implements RouteWrapper<UsernamePasswordAuth> {
  final AuthModelManager modelManager;

  final String authorizationIdKey;

  final bool manageSession;

  final String id;

  final Map<Symbol, MakeParam> makeParams;

  const WrapUsernamePasswordAuth(this.modelManager,
      {this.authorizationIdKey: 'id',
      this.manageSession: true,
      this.id,
      this.makeParams});

  UsernamePasswordAuth createInterceptor() =>
      new UsernamePasswordAuth(this.modelManager,
          authorizationIdKey: this.authorizationIdKey,
          manageSession: manageSession);
}

/// An [Authenticator] for standard username password form style login.
/// It expects a `application/x-www-form-urlencoded` encoded body where the
/// username and password form fields must be called `username` and `password`
/// respectively.
class UsernamePasswordAuth extends Interceptor {
  final AuthModelManager modelManager;

  final String authorizationIdKey;

  final bool manageSession;

  UsernamePasswordAuth(this.modelManager,
      {this.authorizationIdKey: 'id', this.manageSession: true});

  @Input(SessionInterceptor)
  Future<UserModel> pre(Request req, SessionManager sessionManager) async {
    DecodeUrlEncodedForm bodyDecoder = new DecodeUrlEncodedForm();
    Map<String, String> form = await bodyDecoder.pre(req);

    if (form is! Map<String, String>) {
      throw new UnAuthorizedError();
    }

    final String username = form['username'];
    final String password = form['password'];

    if (username is! String) {
      throw new UnAuthorizedError();
    }

    if (password is! String) {
      throw new UnAuthorizedError();
    }

    final subject = await modelManager.authenticate(username, password);

    if (subject == null) {
      throw new UnAuthorizedError();
    }

    if (manageSession is bool && manageSession) {
      await sessionManager
          .updateSession({authorizationIdKey: subject.authorizationId});
    }

    return subject;
  }
}

==> 0.5.0.tar.gz: lib/src/authenticators/user_password.dart <==
part of jaguar_auth.authenticators;

class WrapUsernamePasswordAuth extends RouteWrapper<UsernamePasswordAuth> {
  final AuthModelManager modelManager;

  final String authorizationIdKey;

  final bool manageSession;

  final String id;

  const WrapUsernamePasswordAuth(this.modelManager,
      {this.authorizationIdKey: 'id', this.manageSession: true, this.id});

  UsernamePasswordAuth createInterceptor() =>
      new UsernamePasswordAuth(this.modelManager,
          authorizationIdKey: this.authorizationIdKey,
          manageSession: manageSession);
}

/// An [Authenticator] for standard username password form style login.
/// It expects a `application/x-www-form-urlencoded` encoded body where the
/// username and password form fields must be called `username` and `password`
/// respectively.
class UsernamePasswordAuth extends Interceptor {
  final AuthModelManager modelManager;

  final String authorizationIdKey;

  final bool manageSession;

  UsernamePasswordAuth(this.modelManager,
      {this.authorizationIdKey: 'id', this.manageSession: true});

  @Input(SessionInterceptor)
  Future<UserModel> pre(Request req, SessionManager sessionManager) async {
    DecodeUrlEncodedForm bodyDecoder = new DecodeUrlEncodedForm();
    Map<String, String> form = await bodyDecoder.pre(req);

    if (form is! Map<String, String>) {
      throw new UnAuthorizedError();
    }

    final String username = form['username'];
    final String password = form['password'];

    if (username is! String) {
      throw new UnAuthorizedError();
    }

    if (password is! String) {
      throw new UnAuthorizedError();
    }

    final subject = await modelManager.authenticate(username, password);

    if (subject == null) {
      throw new UnAuthorizedError();
    }

    if (manageSession is bool && manageSession) {
      await sessionManager
          .updateSession({authorizationIdKey: subject.authorizationId});
    }

    return subject;
  }
}
